# `module` `settings_dev` --- ## `class` `Settings` --- #### `property` model_extra Get extra fields set during validation. **Returns:** A dictionary of extra fields, or `None` if `config.extra` is not set to `"allow"`. --- #### `property` model_fields_set Returns the set of fields that have been explicitly set on this model instance. **Returns:** A set of strings representing the fields that have been set, i.e. that were not filled from defaults. --- _This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._